@@ -1,4 +1,4 @@
-#  Copyright 2022 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+#  Copyright 2023 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 #  SPDX-License-Identifier: Apache-2.0
 
 import functools
@@ -220,7 +220,10 @@ def get_output_cache_starting_point():
 
 
 def is_caching_enabled():
-    return os.environ.get(environmental_variables.IS_CACHING_ENABLED).lower() == "true"
+    return (
+        os.environ.get(environmental_variables.IS_CACHING_ENABLED, "false").lower()
+        == "true"
+    )
 
 
 def get_initialiser_stack_tags():
