@@ -1,7 +1,8 @@
-#  Copyright 2022 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+#  Copyright 2023 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 #  SPDX-License-Identifier: Apache-2.0
 
 import configparser
+import functools
 import json
 import logging
 import os
@@ -79,6 +80,7 @@ def load(f, puppet_account_id):
         constants.SERVICE_CONTROL_POLICIES: {},
         constants.SIMULATE_POLICIES: {},
         constants.TAG_POLICIES: {},
+        constants.C7N_AWS_LAMBDAS: {},
     }
     intrinsic_functions_map = get_intrinsic_functions_map(
         manifest_name, puppet_account_id
@@ -163,7 +165,39 @@ def load(f, puppet_account_id):
     return manifest
 
 
-def expand_manifest(manifest, client):
+@functools.lru_cache(maxsize=32)
+def get_ssm_external_account_overrides():
+    result = dict()
+    with betterboto_client.ClientContextManager("ssm") as ssm:
+        paginator = ssm.get_paginator("get_parameters_by_path")
+        for page in paginator.paginate(
+            Path="/servicecatalog-puppet/manifest-external-account-overrides",
+            Recursive=True,
+        ):
+            for parameter in page.get("Parameters", []):
+                _, _, _, account_id, attribute = parameter.get("Name").split("/")
+                if not result.get(account_id):
+                    result[account_id] = dict()
+                result[account_id][attribute] = parameter.get("Value")
+
+    return result
+
+
+def get_ssm_external_account_overrides_for(account_id, value, fail_if_missing):
+    result = get_ssm_external_account_overrides().get(account_id, {})
+    if fail_if_missing and not result:
+        raise Exception(
+            f"There is no override for {account_id} - path /servicecatalog-puppet/manifest-external-account-overrides/{account_id}/xxxx is missing"
+        )
+    result = result.get(value)
+    if fail_if_missing and not result:
+        raise Exception(
+            f"There is no override for {value}.{account_id}. SSM parameter /servicecatalog-puppet/manifest-external-account-overrides/{account_id}/{value} is missing"
+        )
+    return result
+
+
+def expand_manifest(manifest, orgs_client):
     new_manifest = deepcopy(manifest)
     temp_accounts = []
     conversions = dict()
@@ -174,7 +208,9 @@ def expand_manifest(manifest, client):
         if account.get("account_id"):
             account_id = account.get("account_id")
             logger.info("Found an account: {}".format(account_id))
-            expanded_account = expand_account(account, client, account_id, manifest)
+            expanded_account = expand_account(
+                account, orgs_client, account_id, manifest
+            )
             if expanded_account is None:
                 raise Exception(
                     f"You have listed account: {account_id} which is not ACTIVE"
@@ -184,16 +220,18 @@ def expand_manifest(manifest, client):
             ou = account.get("ou")
             logger.info("Found an ou: {}".format(ou))
             if ou.startswith("/"):
-                ou = client.convert_path_to_ou(account.get("ou"))
+                ou = orgs_client.convert_path_to_ou(account.get("ou"))
                 conversions[account.get("ou")] = ou
                 account["ou_name"] = account["ou"]
                 account["ou"] = ou
-            temp_accounts += expand_ou(account, client, manifest)
+            temp_accounts += expand_ou(account, orgs_client, manifest)
 
     for parameter_name, parameter_details in new_manifest.get("parameters", {}).items():
         if parameter_details.get("macro"):
             macro_to_run = macros.get(parameter_details.get("macro").get("method"))
-            result = macro_to_run(client, parameter_details.get("macro").get("args"))
+            result = macro_to_run(
+                orgs_client, parameter_details.get("macro").get("args")
+            )
             parameter_details["default"] = result
             del parameter_details["macro"]
 
@@ -203,7 +241,7 @@ def expand_manifest(manifest, client):
             if parameter_details.get("macro"):
                 macro_to_run = macros.get(parameter_details.get("macro").get("method"))
                 result = macro_to_run(
-                    client, parameter_details.get("macro").get("args")
+                    orgs_client, parameter_details.get("macro").get("args")
                 )
                 parameter_details["default"] = result
                 del parameter_details["macro"]
@@ -236,7 +274,7 @@ def expand_manifest(manifest, client):
         )
         if organizations_account_tags != "ignored":
             tags = list()
-            paginator = client.get_paginator("list_tags_for_resource")
+            paginator = orgs_client.get_paginator("list_tags_for_resource")
             for page in paginator.paginate(ResourceId=stored_account_id,):
                 tags.extend(page.get("Tags", []))
             tags = [f"{t['Key']}:{t['Value']}" for t in tags]
@@ -246,18 +284,37 @@ def expand_manifest(manifest, client):
             elif organizations_account_tags == "honour":
                 stored_account["tags"] = tags
 
-        # append or overwrite if we should
-        if stored_account.get("append"):
-            append = stored_account.get("append")
-            for tag in append.get("tags", []):
-                stored_account["tags"] = stored_account.get("tags", []) + [tag]
-            for region_enabled in append.get("regions_enabled", []):
-                stored_account["regions_enabled"] = stored_account.get(
-                    "regions_enabled", []
-                ) + [region_enabled]
-            del stored_account["append"]
+        # Get tags from orgs if we should
+        external_account_overrides = stored_account.get(
+            "external_account_overrides", {}
+        )
+        if external_account_overrides.get("default_region"):
+            ####
+            if external_account_overrides.get("default_region").get("source") == "ssm":
+                default_region = get_ssm_external_account_overrides_for(
+                    stored_account.get("account_id"),
+                    "default_region",
+                    external_account_overrides.get("default_region").get(
+                        "fail_if_missing", True
+                    ),
+                )
+                if default_region:
+                    stored_account["default_region"] = default_region
+            if external_account_overrides.get("enabled_regions").get("source") == "ssm":
+                enabled_regions = get_ssm_external_account_overrides_for(
+                    stored_account.get("account_id"),
+                    "enabled_regions",
+                    external_account_overrides.get("enabled_regions").get(
+                        "fail_if_missing", True
+                    ),
+                )
+                if enabled_regions:
+                    stored_account["enabled_regions"] = serialisation_utils.load(
+                        enabled_regions
+                    )
 
-        elif stored_account.get("overwrite"):
+        # append or overwrite if we should
+        if stored_account.get("overwrite"):
             overwrite = stored_account.get("overwrite")
             if overwrite.get("tags"):
                 stored_account["tags"] = overwrite.get("tags")
@@ -267,6 +324,16 @@ def expand_manifest(manifest, client):
                 stored_account["default_region"] = overwrite.get("default_region")
             del stored_account["overwrite"]
 
+        elif stored_account.get("append"):
+            append = stored_account.get("append")
+            for tag in append.get("tags", []):
+                stored_account["tags"] = stored_account.get("tags", []) + [tag]
+            for region_enabled in append.get("regions_enabled", []):
+                stored_account["regions_enabled"] = stored_account.get(
+                    "regions_enabled", []
+                ) + [region_enabled]
+            del stored_account["append"]
+
     new_manifest["accounts"] = list(accounts_by_id.values())
 
     for section in [constants.LAUNCHES, constants.STACKS]:
@@ -279,7 +346,7 @@ def expand_manifest(manifest, client):
                         parameter_details.get("macro").get("method")
                     )
                     result = macro_to_run(
-                        client, parameter_details.get("macro").get("args")
+                        orgs_client, parameter_details.get("macro").get("args")
                     )
                     parameter_details["default"] = result
                     del parameter_details["macro"]
@@ -540,7 +607,9 @@ def rewrite_ssm_parameters(manifest):
                         account_id=existing_parameter.get(
                             "account_id", "${AWS::AccountId}"
                         ),
-                        region=existing_parameter.get("region", "${AWS::Region}"),
+                        region=existing_parameter.get(
+                            "region", "${AWS::PuppetAccountId}"
+                        ),
                         client="cloudformation",
                         call="describe_stacks",
                         use_paginator=True,
@@ -761,6 +830,7 @@ class Manifest(dict):
             "tag-policies": "apply_to",
             "simulate-policies": "simulate_for",
             constants.ORGANIZATIONAL_UNITS: "create_in",
+            constants.C7N_AWS_LAMBDAS: "apply_to",
         }.get(section_name)
 
         if (
@@ -914,6 +984,24 @@ class Manifest(dict):
                 name=item.get("name"),
                 tags=item.get("tags"),
             ),
+            constants.C7N_AWS_LAMBDAS: dict(
+                execution=item.get("execution", constants.EXECUTION_MODE_DEFAULT),
+                policies=item.get("policies"),
+                custodian=item.get("custodian"),
+                role_name=item.get(
+                    "role_name", constants.C7N_CUSTODIAN_ROLE_NAME_DEFAULT
+                ),
+                role_path=item.get(
+                    "role_path", constants.C7N_CUSTODIAN_ROLE_PATH_DEFAULT
+                ),
+                schedule_expression=item.get("schedule_expression", ""),
+                role_managed_policy_arns=item.get(
+                    "role_managed_policy_arns",
+                    constants.C7N_CUSTODIAN_MANAGED_POLICY_ARNS_DEFAULT,
+                ),
+                c7n_version=item.get("c7n_version", constants.C7N_VERSION_DEFAULT),
+                c7n_org_version=item.get("c7n_org_version", ""),
+            ),
         }.get(section_name)
 
         common_parameters.update(
@@ -934,33 +1022,35 @@ class Manifest(dict):
                 account_id = str(account.get("account_id"))
                 if single_account != "None" and single_account != account_id:
                     continue
-                additional_parameters = {
-                    "launches": dict(
-                        account_id=account_id, ou=account.get("expanded_from", ""),
-                    ),
-                    "apps": dict(account_id=account_id,),
-                    "workspaces": dict(account_id=account_id,),
-                    "stacks": dict(account_id=account_id,),
-                    "spoke-local-portfolios": dict(
-                        account_id=account_id,
-                        organization=account.get("organization", ""),
-                        ou=account.get("expanded_from", ""),
-                    ),
-                    "imported-portfolios": dict(
-                        account_id=account_id,
-                        organization=account.get("organization", ""),
-                        ou=account.get("expanded_from", ""),
-                    ),
-                    "assertions": dict(account_id=account_id,),
-                    "lambda-invocations": dict(account_id=account_id,),
-                    "code-build-runs": dict(account_id=account_id,),
-                    "service-control-policies": dict(
-                        account_id=account_id, ou_name="",
-                    ),
-                    "tag-policies": dict(account_id=account_id, ou_name="",),
-                    constants.SIMULATE_POLICIES: dict(account_id=account_id,),
-                }.get(section_name)
+
                 if tag_name in account.get("tags"):
+                    additional_parameters = {
+                        "launches": dict(
+                            account_id=account_id, ou=account.get("expanded_from", ""),
+                        ),
+                        "apps": dict(account_id=account_id,),
+                        "workspaces": dict(account_id=account_id,),
+                        "stacks": dict(account_id=account_id,),
+                        "spoke-local-portfolios": dict(
+                            account_id=account_id,
+                            organization=account.get("organization", ""),
+                            ou=account.get("expanded_from", ""),
+                        ),
+                        "imported-portfolios": dict(
+                            account_id=account_id,
+                            organization=account.get("organization", ""),
+                            ou=account.get("expanded_from", ""),
+                        ),
+                        "assertions": dict(account_id=account_id,),
+                        "lambda-invocations": dict(account_id=account_id,),
+                        "code-build-runs": dict(account_id=account_id,),
+                        "service-control-policies": dict(
+                            account_id=account_id, ou_name="",
+                        ),
+                        "tag-policies": dict(account_id=account_id, ou_name="",),
+                        constants.SIMULATE_POLICIES: dict(account_id=account_id,),
+                        constants.C7N_AWS_LAMBDAS: dict(account_id=account_id,),
+                    }.get(section_name)
                     if isinstance(regions, str):
                         if regions in [
                             "enabled",
@@ -1051,6 +1141,7 @@ class Manifest(dict):
                 "tag-policies": dict(account_id=account_id, ou_name="",),
                 constants.SIMULATE_POLICIES: dict(account_id=account_id,),
                 constants.ORGANIZATIONAL_UNITS: dict(account_id=account_id,),
+                constants.C7N_AWS_LAMBDAS: dict(account_id=account_id,),
             }.get(section_name)
 
             if isinstance(regions, str):
@@ -1556,6 +1647,16 @@ def parse_conditions(manifest):
     return manifest
 
 
+def rewrite_c7n_cloudtrails(manifest):
+    if manifest.get(constants.C7N_AWS_CLOUDTRAILS):
+        manifest[constants.C7N_AWS_LAMBDAS] = manifest[constants.C7N_AWS_CLOUDTRAILS]
+        del manifest[constants.C7N_AWS_CLOUDTRAILS]
+        for item_name, item in manifest[constants.C7N_AWS_LAMBDAS].items():
+            for policy in item["policies"]:
+                policy["mode"]["type"] = "cloudtrail"
+    return manifest
+
+
 def rewrite_organizational_units(manifest, conversions, client):
     for item_name, item in manifest.get(constants.ORGANIZATIONAL_UNITS, {}).items():
         path = item.get("path")
